# <u>PyEmailerAJM</u>
### <i>Makes automating Outlook emails quick and easy</i>

- PyEmailerAJM uses pywin32 to automate the sending/reading of Outlook emails.

**Import**

- import PyEmailer class using `from PyEmailerAJM.PyEmailerAJM import PyEmailer`

**Notes**

- see [OutlookPywin32Commands.xlsx](OutlookPywin32Commands.xlsx) for list of commands that can be used with a message object.

- Email signature **text** can now be added as of v1.4
  - Assuming the signature *.txt file is found in `%APPDATA%/Microsoft/Signatures/`